# Class: clamav::server
#
#
class clamav::server {
    include clamav
    include exim

    package { "clamd":
        name => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => "clamav-daemon",
            default => "clamd",
        },
        ensure => installed,
        require => Package["clamav"],
    }

    service { "clamd":
        name => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => "clamav-daemon",
            default => "clamd",
        },
        ensure => running,
        enable => true,
        hasrestart => true,
        hasstatus  => true,
        require => Package["clamd"],
    }

    file { "/etc/clamd.conf":
        path => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => "/etc/clamav/clamd.conf",
            default => "/etc/clamd.conf",
        },
        content => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => template("clamav/debclamd.conf.erb"),
            default => template("clamav/clamd.conf.erb"),
        },
        require => Package["clamd"],
        notify => Service["clamd"],
    }

    file { "/etc/freshclam.conf":
        path => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => "/etc/clamav/freshclam.conf",
            default => "/etc/freshclam.conf",
        },
        content => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => template("clamav/debfreshclam.conf.erb"),
            default => template("clamav/freshclam.conf.erb"),
        },
        mode    => "0644",
        owner   => "root",
        group   => "root",
        require => Package["clamav"],
    }

    exec { "freshclam":
        command => "freshclam",
        path    => "/usr/bin:/bin",
        require => [Package["clamd"], File["/etc/freshclam.conf"]],
        timeout => 600,
        unless  => "ls /var/lib/clamav/main.c?d &>/dev/null",
    }

    user { "clam":
        name => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => "clamav",
            default => "clam",
        },
        groups => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => ["clamav", "Debian-exim"],
            default => ["clam", "exim"],
        },
        require => [Package["exim"], Package["clamav"]],
        notify => Service["clamd"],
    }
}