# Class: openldap::server
#
#
class openldap::server {
    package { "openldap-servers":
        ensure => installed,
    }

    file { "/etc/openldap/slapd.conf":
        content => template("openldap/slapd.conf.erb"),
        require => [Package["openldap-servers"],
                    File["/etc/openldap/schema/baruwa.schema"],
                    File["/var/lib/ldap/baruwa.net"],
                    File["/var/log/openldap"],],
        notify => Service["slapd"],
    }

    exec { "rm-ldif-conf":
        command => "/bin/mv -f /etc/openldap/slapd.d /etc/openldap/slapd.d.disabled",
        onlyif => "ls /etc/openldap/slapd.d",
        require => Package["openldap-servers"],
    }

    service { "slapd":
        ensure => running,
        enable => true,
        hasrestart  => true,
        hasstatus   => true,
        require => Exec["rm-ldif-conf"],
    }

    file { "/var/lib/ldap/baruwa.net/DB_CONFIG":
        content => template("openldap/DB_CONFIG.erb"),
        require => File["/var/lib/ldap/baruwa.net"],
        owner => 'ldap',
        group => 'ldap',
    }

    file { "/etc/openldap/schema/baruwa.schema":
        content => template("openldap/baruwa.schema.erb"),
        require => Package["openldap-servers"],
        owner => 'root',
        group => 'root',
        mode => '0644',
    }

    file { "/var/lib/ldap/baruwa.net":
        ensure => directory,
        owner => "ldap",
        group => "ldap",
        mode => "0700",
        require => Package["openldap-servers"],
    }

    file { "/var/log/openldap":
        ensure => directory,
        owner => "ldap",
        group => "ldap",
        mode => "0755",
        require => Package["openldap-servers"],
    }
}